import { fixture, html as html$1, expect } from '@open-wc/testing';
import { svg, css, html } from 'lit';
import { UUIHorizontalShakeKeyframes, UUIHorizontalShakeAnimationValue } from '@umbraco-ui/uui-base/lib/animations';
import { UUIBooleanInputBaseElement } from '@umbraco-ui/uui-base/lib/uui-boolean-input';

const iconCheck = svg`<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512">
<path d="M461.884 68.14c-132.601 81.297-228.817 183.87-272.048 235.345l-105.874-82.95-46.751 37.691 182.941 186.049c31.485-80.646 131.198-238.264 252.956-350.252L461.884 68.14z"/>
</svg>`;
const iconWrong = svg`<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512">
<path d="M422.952 371.305L307.064 255.418l115.884-115.887-51.722-51.723L255.34 203.693 139.457 87.812l-51.726 51.719 115.885 115.885L87.731 371.305l51.726 51.721L255.344 307.14l115.884 115.882z"/>
</svg>`;

class UUIToggleElement extends UUIBooleanInputBaseElement {
  constructor() {
    super("switch");
  }
  renderCheckbox() {
    return html`
      <div id="slider">
        <div id="icon-check">${iconCheck}</div>
        <div id="icon-wrong">${iconWrong}</div>
      </div>
    `;
  }
}
UUIToggleElement.styles = [
  ...UUIBooleanInputBaseElement.styles,
  UUIHorizontalShakeKeyframes,
  css`
      :host {
        --uui-toggle-size: 18px;
        --uui-toggle-switch-width: calc(2 * var(--uui-toggle-size));
      }

      #slider {
        position: relative;
        grid-area: 'input';
        display: flex;
        align-items: center;

        width: var(--uui-toggle-switch-width);
        height: var(--uui-toggle-size);
        border-radius: 100px;

        background-color: var(
          --uui-toggle-background-color,
          var(--uui-interface-surface-alt,#d8d7d9)
        );
        border: 1px solid
          var(--uui-toggle-border-color, var(--uui-interface-border,#C4C4C4));
        font-size: calc(var(--uui-toggle-size) * 0.6);
      }
      label:hover input:not([disabled]) + #slider {
        border-color: var(
          --uui-toggle-border-color-hover,
          var(--uui-interface-border-hover,rgb(179, 179, 179))
        );
        background-color: var(
          --uui-toggle-background-color-hover,
          var(--uui-interface-surface-alt-hover,rgb(200, 200, 200))
        );
      }
      label:focus #slider {
        border-color: var(
          --uui-toggle-border-color-focus,
          var(--uui-interface-border-focus,rgb(179, 179, 179))
        );
        background-color: var(
          --uui-toggle-background-color-focus,
          var(--uui-interface-surface-alt-focus,#d8d7d9)
        );
      }
      input:checked + #slider {
        background-color: var(--uui-interface-select,#3544B1);
      }
      label:hover input:checked:not([disabled]) + #slider {
        background-color: var(--uui-interface-select-hover,rgb(70, 86, 200));
      }
      label:focus input:checked + #slider {
        background-color: var(--uui-interface-select-focus,#3544B1);
      }

      #icon-check,
      #icon-wrong {
        position: absolute;
        vertical-align: middle;
        width: 1em;
        height: 1em;
        line-height: 0;
        transition: fill 120ms;
      }

      #icon-check {
        margin-left: -0.5em;
        left: calc(var(--uui-toggle-size) * 0.5);
        fill: var(--uui-interface-contrast,#060606);
      }

      #icon-wrong {
        margin-right: -0.5em;
        right: calc(var(--uui-toggle-size) * 0.5);
        fill: var(--uui-interface-contrast,#060606);
      }
      input:checked + #slider #icon-check {
        fill: var(--uui-interface-select-contrast,#FEFEFE);
      }

      #slider::after {
        content: '';
        position: absolute;
        top: 2px;
        left: 2px;
        width: calc(var(--uui-toggle-size) - 4px);
        height: calc(var(--uui-toggle-size) - 4px);
        border-radius: 100px;
        background-color: var(--uui-interface-select-contrast,#FEFEFE);
        transition: width 120ms ease, left 120ms ease, transform 120ms ease,
          background-color 120ms;
      }

      input:checked + #slider::after {
        left: calc(100% - 2px);
        transform: translateX(-100%);
      }

      :host(:not([disabled])) label:active #slider::after {
        /** Stretch when mouse down */
        width: calc(1.06 * var(--uui-toggle-size));
      }

      :host([disabled]) #slider {
        background-color: var(--uui-interface-surface-alt-disabled,rgb(204, 204, 204));
      }
      :host([disabled]) input:checked + #slider {
        background-color: var(--uui-interface-select-disabled,rgb(87, 87, 87));
      }
      :host([disabled]) #slider::after {
        background-color: var(--uui-interface-surface-disabled,rgb(228, 228, 228));
      }
      :host([disabled]) #slider #icon-wrong {
        fill: var(--uui-interface-contrast-disabled,rgb(115, 113, 110));
      }
      :host([disabled]) label:active #slider {
        -webkit-animation: ${UUIHorizontalShakeAnimationValue};
                animation: ${UUIHorizontalShakeAnimationValue};
      }
      :host([disabled]) input:checked + #slider #icon-check {
        fill: var(--uui-interface-select-contrast-disabled,rgb(228, 228, 228));
      }

      :host([error]) #slider {
        border: 1px solid var(--uui-look-danger-border, #d42054);
      }

      :host([error]) label:hover #slider {
        border: 1px solid var(--uui-look-danger-border, #d42054);
      }
    `
];
UUIToggleElement.formAssociated = true;

customElements.define("uui-toggle", UUIToggleElement);

describe("UuiToggle", () => {
  let element;
  let input;
  beforeEach(async () => {
    var _a;
    element = await fixture(html$1` <uui-toggle label="test label" name="test"></uui-toggle> `);
    input = (_a = element.shadowRoot) == null ? void 0 : _a.querySelector("#input");
  });
  it("passes the a11y audit", async () => {
    await expect(element).shadowDom.to.be.accessible();
  });
  it("native input has a correct role", async () => {
    expect(input).to.have.attr("role", "switch");
  });
});
